@@ -26,6 +26,7 @@ from subprocess import CalledProcessError
 
 import pytest
 
+from tests_common.test_utils.taskinstance import run_task_instance
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 if AIRFLOW_V_3_0_PLUS:
@@ -33,7 +34,10 @@ if AIRFLOW_V_3_0_PLUS:
 else:
     from airflow.decorators import setup, task, teardown  # type: ignore[attr-defined,no-redef]
 
-from airflow.utils import timezone
+try:
+    from airflow.utils import timezone  # type: ignore[attr-defined]
+except AttributeError:
+    from airflow.sdk import timezone
 
 pytestmark = pytest.mark.db_test
 
@@ -67,7 +71,7 @@ def venv_python_with_cloudpickle_and_dill(tmp_path_factory):
     venv_dir = tmp_path_factory.mktemp("venv_serializers")
     venv.create(venv_dir, with_pip=True)
     python_path = (venv_dir / "bin" / "python").resolve(strict=True).as_posix()
-    subprocess.call([python_path, "-m", "pip", "install", "cloudpickle", "dill"])
+    subprocess.check_call([python_path, "-m", "pip", "install", "cloudpickle", "dill"])
     return python_path
 
 
@@ -87,11 +91,11 @@ class TestExternalPythonDecorator:
             import dill  # noqa: F401
 
         with dag_maker(serialized=True):
-            f()
+            v = f()
 
         dr = dag_maker.create_dagrun()
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -113,10 +117,10 @@ class TestExternalPythonDecorator:
             import dill  # noqa: F401
 
         with dag_maker(serialized=True):
-            f()
+            v = f()
         dr = dag_maker.create_dagrun()
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -131,12 +135,12 @@ class TestExternalPythonDecorator:
             pass
 
         with dag_maker(serialized=True):
-            f()
+            v = f()
         dr = dag_maker.create_dagrun()
         ti = dr.get_task_instances()[0]
 
         with pytest.raises(CalledProcessError):
-            ti.run()
+            run_task_instance(ti, v.operator)
 
     def test_exception_raises_error(self, dag_maker, venv_python):
         @task.external_python(python=venv_python)
@@ -144,12 +148,12 @@ class TestExternalPythonDecorator:
             raise Exception
 
         with dag_maker(serialized=True):
-            f()
+            v = f()
         dr = dag_maker.create_dagrun()
         ti = dr.get_task_instances()[0]
 
         with pytest.raises(CalledProcessError):
-            ti.run()
+            run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -168,10 +172,10 @@ class TestExternalPythonDecorator:
             raise Exception
 
         with dag_maker(serialized=True):
-            f(0, 1, c=True)
+            v = f(0, 1, c=True)
         dr = dag_maker.create_dagrun()
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -188,11 +192,11 @@ class TestExternalPythonDecorator:
             return None
 
         with dag_maker(serialized=True):
-            f()
+            v = f()
 
         dr = dag_maker.create_dagrun()
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -209,11 +213,11 @@ class TestExternalPythonDecorator:
             return None
 
         with dag_maker(serialized=True):
-            f(datetime.datetime.now(tz=datetime.timezone.utc))
+            v = f(datetime.datetime.now(tz=datetime.timezone.utc))
 
         dr = dag_maker.create_dagrun()
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -233,14 +237,14 @@ class TestExternalPythonDecorator:
             return 1
 
         with dag_maker(serialized=True) as dag:
-            f()
+            v = f()
         dr = dag_maker.create_dagrun()
 
         assert len(dag.task_group.children) == 1
         setup_task = dag.task_group.children["f"]
         assert setup_task.is_setup
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -260,14 +264,14 @@ class TestExternalPythonDecorator:
             return 1
 
         with dag_maker(serialized=True) as dag:
-            f()
+            v = f()
         dr = dag_maker.create_dagrun()
 
         assert len(dag.task_group.children) == 1
         teardown_task = dag.task_group.children["f"]
         assert teardown_task.is_teardown
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
 
     @pytest.mark.parametrize(
         "serializer",
@@ -288,7 +292,7 @@ class TestExternalPythonDecorator:
             return 1
 
         with dag_maker(serialized=True) as dag:
-            f()
+            v = f()
         dr = dag_maker.create_dagrun()
 
         assert len(dag.task_group.children) == 1
@@ -296,4 +300,4 @@ class TestExternalPythonDecorator:
         assert teardown_task.is_teardown
         assert teardown_task.on_failure_fail_dagrun is on_failure_fail_dagrun
         ti = dr.get_task_instances()[0]
-        ti.run()
+        run_task_instance(ti, v.operator)
